/* SPDX-License-Identifier: GPL-2.0-only */

#ifndef __SOC_MEDIATEK_MT8188_INCLUDE_SOC_DP_INTF_H__
#define __SOC_MEDIATEK_MT8188_INCLUDE_SOC_DP_INTF_H__

#include <soc/dp_intf_v1.h>

#endif /* __SOC_MEDIATEK_MT8188_INCLUDE_SOC_DP_INTF_H__ */
